@@ -14,7 +14,7 @@ IMPLEMENT_STANDARD_RTTIEXT(ISession_Curve,AIS_InteractiveObject)
 static char THIS_FILE[]=__FILE__;
 #endif
 
-void ISession_Curve::Compute (const Handle(PrsMgr_PresentationManager3d)& ,
+void ISession_Curve::Compute (const Handle(PrsMgr_PresentationManager)& ,
                               const Handle(Prs3d_Presentation)& thePrs,
                               const Standard_Integer theMode)
 {
